/* $Workfile: OtxRawD.h $   $Revision: 5 $    $Modtime: 6/21/01 2:18p $  */
#ifndef OTX_RAWDATA_DEF_H
#define OTX_RAWDATA_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxRawD

  Copyright (C) 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module                                        
  OtxRawD | Constants, Macros, and Types for the Raw Data Functions

  @contents2
  OtxRawD.h |

  @index enum type struct | OtxRawD

  @contents2
  OTX Raw Data Device Macros, Constants, and Types |

  @head3 OtxRawDataXXX Macro, Constant, and Type Reference |

  @index enum type struct | OtxRawD

*******************************************************************************/

#ifdef __cplusplus
  extern "C" {
#endif

#if 0
#define OTX_RAWDATA_MAX_TX_FRAME_LEN    8192
#define OTX_RAWDATA_MAX_RX_FRAME_LEN    8192
#else // Temporary reduced. Will be brought back to 8192 in future releases
#define OTX_RAWDATA_MAX_TX_FRAME_LEN    2048
//#define OTX_RAWDATA_MAX_RX_FRAME_LEN    2048
#endif

/*---------------------------------------------------------------------------*\
  @enum 
    RAWDATA Receiver Attributes
\*---------------------------------------------------------------------------*/
enum OtxRawDataReceiverAttributesE {
  OTX_ATTR_RAWDATA_RECEIVER_FIFO_SIZE = OTX_ATTR_END + 0,            // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                    // Fifo buffer size factor for received data in the driver.
                                                                    // The fifo is allocated when the logical device is connected.
                                                                    // Total fifo size in bytes is this attribute * (PipeCapacity/64).
  OTX_ATTR_RAWDATA_RECEIVER_GENERATE_DATA_EVENTS = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_BOOL) Read/Write.
                                                                    // If set to OTX_TRUE (default) the device will generate
                                                                    // a <e OtxRawDataReceiverEventCodesE.OTX_RAWDATA_RECEIVER_EC_DATA_AVAILABLE> 
                                                                    // event when the device has any data to be retrieved from the driver buffer.
                                                                    // By setting this attribute to OTX_FALSE, such events
                                                                    // are not generated, thus reducing event handling processing overhead.
  OTX_ATTR_RAWDATA_RECEIVER_END                 = OTX_ATTR_END + 2
};
typedef enum OtxRawDataReceiverAttributesE OtxRawDataReceiverAttributesE;


/*---------------------------------------------------------------------------*\
  @enum
    RAWDATA Receiver Event Codes
\*---------------------------------------------------------------------------*/
enum OtxRawDataReceiverEventCodesE {
  OTX_RAWDATA_RECEIVER_EC_DATA_AVAILABLE      = 0x00, // @emem Raw Data is available to 
                                                      // be retrieved by calling <f OtxRawDataReadData>
                                                      // Generation of this event can be blocked by setting the
                                                      // <e OtxRawDataReceiverAttributesE.OTX_ATTR_RAWDATA_RECEIVER_GENERATE_DATA_EVENTS>
                                                      // attribute to OTX_FALSE.

  OTX_RAWDATA_RECEIVER_EC_BUFFER_OVERRUN      = 0x01, // @emem Raw Data Buffer Overrun. 
                                                      // The host is too slow retrieving 
                                                      // the data from the Raw Data Receiver
  OTX_RAWDATA_RECEIVER_EC_FLAG_FILTERING      = 0x02, // @emem Flag encountered. Filtering 
                                                      // incoming data

  OTX_RAWDATA_RECEIVER_END_OF_EVENT_CODES
};

typedef enum OtxRawDataReceiverEventCodesE OtxRawDataReceiverEventCodesE;


/*---------------------------------------------------------------------------*\
  @enum
    RAWDATA Receiver Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxRawDataReceiverResultCodesE {

  OTX_RAWDATA_RECEIVER_RES_END = OTX_RES_END + 0
};

typedef enum OtxRawDataReceiverResultCodesE OtxRawDataReceiverResultCodesE;


/*---------------------------------------------------------------------------*\
  @enum 
    RAWDATA Sender Attributes
\*---------------------------------------------------------------------------*/
enum OtxRawDataSenderAttributesE {
  OTX_ATTR_RAWDATA_SENDER_GENERATE_DATA_EVENTS = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_BOOL) Read/Write.
                                                                    // If set to OTX_TRUE (default) the device will generate
                                                                    // a <e OtxRawDataSenderEventCodesE.OTX_RAWDATA_SENDER_EC_BUF_DEPLETED> 
                                                                    // event when the device is ready
                                                                    // to accept more data. By setting this attribute to OTX_FALSE, such events
                                                                    // are not generated, thus reducing event handling processing overhead.
  OTX_ATTR_RAWDATA_SENDER_END                 = OTX_ATTR_END + 1
};
typedef enum OtxRawDataSenderAttributesE OtxRawDataSenderAttributesE;

/*---------------------------------------------------------------------------*\
  @enum
    Raw Data Sender Event Codes
\*---------------------------------------------------------------------------*/
enum OtxRawDataSenderEventCodesE {
  OTX_RAWDATA_SENDER_EC_COMPLETED      = 0x00, // @emem  Raw Data completely sent. 
                                               // Now sending flags.
  OTX_RAWDATA_SENDER_EC_BUF_DEPLETED   = 0x01, // @emem  Raw Data Sender buffer depleted. 
                                               // Now accepting more data.
                                               // Generation of this event can be blocked by setting the
                                               // <e OtxRawDataSenderAttributesE.OTX_ATTR_RAWDATA_SENDER_GENERATE_DATA_EVENTS>
                                               // attribute to OTX_FALSE.

  OTX_RAWDATA_SENDER_END_OF_EVENT_CODES
};

typedef enum OtxRawDataSenderEventCodesE OtxRawDataSenderEventCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Raw Data Sender Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxRawDataSenderResultCodesE {
  OTX_RAWDATA_SENDER_RES_TX_BUSY                  =  OTX_RES_END +  0,  // @emem Transmitter queue is full.
  OTX_RAWDATA_SENDER_RES_FRAME_TOO_LONG           =  OTX_RES_END +  1,  // @emem Data buffer too long.

  OTX_RAWDATA_SENDER_RES_END                      =  OTX_RES_END +  2
};

typedef enum OtxRawDataSenderResultCodesE OtxRawDataSenderResultCodesE;



#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif // OTX_RAWDATA_DEF_H
